==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nadpisz plik?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">&apos;&amp;#39; Plik już istnieje. Czy chcesz go zastąpić?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-3"/>
        <source>File Format Version Not Recommended</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wersja formatu pliku Nie poleca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wersja formatu używasz nie jest zalecane:&apos;&amp;#39;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wszystkie czarne podmioty i warstwy będą zapisywane jako białe.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Saved drawing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wszystkie niestandardowe kolory zostaną &quot;zaokrąglone&amp;quot; do najbliższego stałego koloru. Kontynuować?</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Saving...</source>
        <translatorcomment>--ignored ...--
--file: qvfb_pl.ts--
Zapisywanie... </translatorcomment>
        <translation type="unfinished">Zapisywanie...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zapisywanie do pliku&apos;&amp;#39; wersję formatu.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Czarne podmioty i warstwy są zapisywane jako białe.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Niestandardowe kolory są &quot;zaokrąglone&amp;quot; do najbliższego stałego koloru.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Plik nie został zapisany.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zapisywanie rysunku: %1</translatorcomment>
        <translation type="obsolete">Zapisywanie rysunku: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Zapisz
Zapisz &amp;wszystko</translatorcomment>
        <translation type="unfinished">&amp;Zapisz</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastąpić plik?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Plik „%1” już istnieje. Zastąpić go?</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Wszystkie dostosowane kolory zostaną przybliżone najbliższymi ustalonymi kolorami.</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>File Format Version Not Recommended</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie zalecana wersja formatu pliku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Używana wersja formatu pliku nie jest zalecana: „%1”.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation>Dostosowane właściwości nie zostaną zapisane.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wszystkie czarne elementy i warstwy zostaną zapisywane jako białe.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>Kontynuować?</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Saved drawing:</source>
        <translation>Zapisany rysunek:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wszystkie niestandardowe kolory zostaną &quot;zaokrąglone&amp;quot; do najbliższego stałego koloru. Kontynuować?</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Saving...</source>
        <translatorcomment>--ignored ...--
--file: qvfb_pl.ts--
Zapisywanie... </translatorcomment>
        <translation>Zapisywanie...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zapisywanie do pliku w wersji formatu &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Czarne obiekty i warstwy są zapisywane jako białe.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dostosowane kolory są przybliżane najbliższymi ustalonymi kolorami.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie zapisano pliku %1.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zapisywanie rysunku: %1</translatorcomment>
        <translation type="obsolete">Zapisywanie rysunku: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Zapisz
Zapisz &amp;wszystko</translatorcomment>
        <translation>&amp;Zapisz</translation>
    </message>
</context>
</TS>
